@@ -3,7 +3,7 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|  \_
+#  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
@@ -20,9 +20,9 @@ def _check_target_size(size):
     """
 
     if not isinstance(size, (list, tuple)):
-        raise ValueError("Size must be a tuple")
+        raise ValueError("`target_size` must be a tuple of length 2 `(width,height)`")
     if len(size) != 2:
-        raise ValueError("Size must be a tuple of length 2")
+        raise ValueError("`target_size` must be a tuple of length 2 `(width,height)`")
     if size[0] < 0 or size[1] < 0:
         raise ValueError("Width and height must be >= 0")
 
@@ -68,13 +68,13 @@ def _get_output(array, out, fname, dtype=None, output=None):
         (2) else verify that output is of right size, shape, and contiguous
     Parameters
     ----------
-    array : ndarray
-    out : ndarray or None
+    array : Tensor
+    out : Tensor or None
     fname : str
         Function name. Used in error messages
     Returns
     -------
-    output : ndarray
+    output : Tensor
     '''
     detail = '.\nWhen an output argument is used, the checking is very strict as this is a performance feature.'
     if dtype is None:
@@ -109,7 +109,7 @@ def _get_axis(array, axis, fname):
     Checks that ``axis`` is a valid axis of ``array`` and normalises it.
     Parameters
     ----------
-    array : ndarray
+    array : Tensor
     axis : int
     fname : str
         Function name. Used in error messages
@@ -135,7 +135,7 @@ def _normalize_sequence(array, value, fname):
     each dimension of array.
     Parameters
     ----------
-    array : ndarray
+    array : Tensor
     value : sequence or scalar
     fname : str
         Function name. Used in error messages
@@ -159,7 +159,7 @@ def _verify_is_floatingpoint_type(A, function_name):
     ``TypeError``.
     Parameters
     ----------
-    A : ndarray
+    A : Tensor
     function_name : str
         Used for error messages
     '''
@@ -174,7 +174,7 @@ def _verify_is_integer_type(A, function_name):
     ``TypeError``.
     Parameters
     ----------
-    A : ndarray
+    A : Tensor
     function_name : str
         Used for error messages
     '''
@@ -190,7 +190,7 @@ def _verify_is_nonnegative_integer_type(A, function_name):
     ``TypeError``.
     Parameters
     ----------
-    A : ndarray
+    A : Tensor
     function_name : str
         Used for error messages
     '''
