@@ -8,9 +8,3 @@
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
-
-
-
-__all__ = [
-    
-]
\ No newline at end of file
