@@ -3,7 +3,7 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|  \_
+#  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
@@ -13,6 +13,7 @@
 #pylint:disable=redefined-outer-name
 
 import os
+from ..jit.annotations import List
 
 _acceptable_video_formats = ('.mp4', '.avi', '.mov', '.mkv', '.webm')
 _acceptable_image_formats = ('.jpg', '.jpeg', '.png', '.bmp', '.tif', '.tiff')
@@ -25,7 +26,8 @@ __all__ = [
     'mkdir',
     'listdir',
     'is_image',
-    'is_video'
+    'is_video',
+    'isfile',
     'cwd',
     'exists',
     'minijoin',
@@ -37,105 +39,81 @@ __all__ = [
 ]
 
 
-def list_images(DIR, include_subdirs=True, use_fullpath=False, show_size=False, verbose=1):
-    """
-        Lists all image files within a specific directory (and sub-directories if `include_subdirs=True`)
+def list_images(DIR, recursive=True, use_fullpath=False, show_size=False, verbose=1) -> List[str]:
+    r"""
+        Lists all image files within a specific directory (and sub-directories if `recursive=True`)
     
-    Parameters
-    ----------
-        DIR : str
-            Directory to search for image files
-        include_subdirs : bool
-            Indicate whether to search all subdirectories as well (default = False)
-        use_fullpath : bool
-            Include full filepaths in the returned list (default = False)
-        show_size : bool
-            Prints the disk size of the image files (default = False)
+    Args:
+        DIR (str): Directory to search for image files
+        recursive (bool): Indicate whether to search all subdirectories as well (default = False)
+        use_fullpath (bool): Include full filepaths in the returned list (default = False)
+        show_size (bool): Prints the disk size of the image files (default = False)
     
-    Returns
-    ----------
-        image_files : list
-            List of names (or full filepaths if `use_fullpath=True`) of the image files
+    Returns:
+        image_files (list): List of names (or full filepaths if `use_fullpath=True`) of the image files
+
     """
-    images = _get_media_from_dir(DIR=DIR, include_subdirs=include_subdirs, use_fullpath=use_fullpath, show_size=show_size, list_image_files=True, verbose=verbose)
+    images = _get_media_from_dir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, show_size=show_size, list_image_files=True, verbose=verbose)
 
     if images is not None:   
         return images # images is a list
 
 
-def list_videos(DIR, include_subdirs=True, use_fullpath=False, show_size=False, verbose=1):
-    """
-        Lists all video files within a specific directory (and sub-directories if `include_subdirs=True`)
+def list_videos(DIR, recursive=True, use_fullpath=False, show_size=False, verbose=1) -> List[str]:
+    r"""
+        Lists all video files within a specific directory (and sub-directories if `recursive=True`)
     
-    Parameters
-    ----------
-        DIR : str
-            Directory to search for video files
-        include_subdirs : bool
-            Indicate whether to search all subdirectories as well (default = False)
-        use_fullpath : bool
-            Include full filepaths in the returned list (default = False)
-        show_size : bool
-            Prints the disk size of the video files (default = False)
+    Args:
+        DIR (str): Directory to search for video files
+        recursive (bool): Indicate whether to search all subdirectories as well (default = False)
+        use_fullpath (bool): Include full filepaths in the returned list (default = False)
+        show_size (bool): Prints the disk size of the video files (default = False)
     
-    Returns
-    ----------
-        video_files : list
-            List of names (or full filepaths if `use_fullpath=True`) of the video files
+    Returns:
+        video_files (list): List of names (or full filepaths if `use_fullpath=True`) of the video files
+
     """
 
-    videos = _get_media_from_dir(DIR=DIR, include_subdirs=include_subdirs, use_fullpath=use_fullpath, show_size=show_size, list_video_files=True, verbose=verbose)
+    videos = _get_media_from_dir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, show_size=show_size, list_video_files=True, verbose=verbose)
 
     if videos is not None:   
         return videos # videos is a list
 
 
-def list_media(DIR, include_subdirs=True, use_fullpath=False, show_size=True, verbose=0):
-    """
-        Lists all media files within a specific directory (and sub-directories if `include_subdirs=True`)
+def list_media(DIR, recursive=True, use_fullpath=False, show_size=True, verbose=0) -> List[str]:
+    r"""
+        Lists all media files within a specific directory (and sub-directories if `recursive=True`)
     
-    Parameters
-    ----------
-        DIR : str
-            Directory to search for media files
-        include_subdirs : bool
-            Indicate whether to search all subdirectories as well (default = False)
-        use_fullpath : bool
-            Include full filepaths in the returned list (default = False)
-        show_size : bool
-            Prints the disk size of the media files (default = False)
+    Args:
+        DIR (str): Directory to search for media files
+        recursive (bool): Indicate whether to search all subdirectories as well (default = False)
+        use_fullpath (bool): Include full filepaths in the returned list (default = False)
+        show_size (bool): Prints the disk size of the media files (default = False)
     
-    Returns
-    ----------
-        media_files : list
-            List of names (or full filepaths if `use_fullpath=True`) of the media files
+    Returns:
+        media_files (list): List of names (or full filepaths if `use_fullpath=True`) of the media files
+
     """
 
-    media = _get_media_from_dir(DIR=DIR, include_subdirs=include_subdirs, use_fullpath=use_fullpath, show_size=show_size, list_image_files=True, list_video_files=True, verbose=verbose)
+    media = _get_media_from_dir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, show_size=show_size, list_image_files=True, list_video_files=True, verbose=verbose)
 
     if media is not None:   
         return media # media is a list
 
 
-def _get_media_from_dir(DIR, include_subdirs=True, use_fullpath=False, show_size=True,  list_image_files=False, list_video_files=False, verbose=1):
-    """
-        Lists all media files within a specific directory (and sub-directories if `include_subdirs=True`)
+def _get_media_from_dir(DIR, recursive=True, use_fullpath=False, show_size=True,  list_image_files=False, list_video_files=False, verbose=1) -> List[str]:
+    r"""
+        Lists all media files within a specific directory (and sub-directories if `recursive=True`)
     
-    Parameters
-    ----------
-        DIR : str
-            Directory to search for media files
-        include_subdirs : bool
-            Indicate whether to search all subdirectories as well (default = False)
-        use_fullpath : bool
-            Include full filepaths in the returned list (default = False)
-        show_size : bool
-            Prints the disk size of the media files (default = False)
+    Args:
+        DIR (str): Directory to search for media files
+        recursive (bool): Indicate whether to search all subdirectories as well (default = False)
+        use_fullpath (bool): Include full filepaths in the returned list (default = False)
+        show_size (bool): Prints the disk size of the media files (default = False)
     
-    Returns
-    ----------
-        media_files : list
-            List of names (or full filepaths if `use_fullpath=True`) of the media files
+    Returns:
+        media_files (list): List of names (or full filepaths if `use_fullpath=True`) of the media files
+
     """
 
     if not exists(DIR):
@@ -150,7 +128,7 @@ def _get_media_from_dir(DIR, include_subdirs=True, use_fullpath=False, show_size
     size_image_list = 0
     size_video_list = 0
     
-    if include_subdirs:
+    if recursive:
         for root, _, files in os.walk(DIR):
             for file in files:
                 fullpath = minijoin(root, file).replace('\\', '/')
@@ -231,32 +209,26 @@ def _get_media_from_dir(DIR, include_subdirs=True, use_fullpath=False, show_size
         
 
 
-def listdir(DIR, include_subdirs=True, use_fullpath=False, show_size=True, verbose=1):
-    """
-        Lists all files within a specific directory (and sub-directories if `include_subdirs=True`)
+def listdir(DIR, recursive=True, use_fullpath=False, show_size=True, verbose=1) -> List[str]:
+    r"""
+        Lists all files within a specific directory (and sub-directories if `recursive=True`)
     
-    Parameters
-    ----------
-        DIR : str
-            Directory to search for files
-        include_subdirs : bool
-            Indicate whether to search all subdirectories as well (default = False)
-        use_fullpath : bool
-            Include full filepaths in the returned list (default = False)
-        show_size : bool
-            Prints the disk size of the files (default = False)
+    Args:
+        DIR (str): Directory to search for files
+        recursive (bool): Indicate whether to search all subdirectories as well (default = False)
+        use_fullpath (bool): Include full filepaths in the returned list (default = False)
+        show_size (bool): Prints the disk size of the files (default = False)
     
-    Returns
-    ----------
-        files : list
-            List of names (or full filepaths if `use_fullpath=True`) of the files
+    Returns:
+        files (list): List of names (or full filepaths if `use_fullpath=True`) of the files
+
     """
 
     if not exists(DIR):
         raise ValueError('Specified directory does not exist')
     
-    if not isinstance(include_subdirs, bool):
-        raise ValueError('include_subdirs must be a boolean')
+    if not isinstance(recursive, bool):
+        raise ValueError('recursive must be a boolean')
 
     if not isinstance(use_fullpath, bool):
         raise ValueError('use_fullpath must be a boolean')
@@ -268,7 +240,7 @@ def listdir(DIR, include_subdirs=True, use_fullpath=False, show_size=True, verbo
     count_files= 0
     size_dirs_list = 0
     
-    if include_subdirs:
+    if recursive:
         for root, _, files in os.walk(DIR):
             for file in files:
                 fullpath = minijoin(root, file).replace('\\', '/')
@@ -300,19 +272,17 @@ def listdir(DIR, include_subdirs=True, use_fullpath=False, show_size=True, verbo
     return dirs
 
 
-def is_image(path):
-    """
+def is_image(path) -> bool:
+    r"""
         Checks if a given path is that of a valid image file
             
-    Parameters
-    ----------
-        path : str
-            Filepath to check
+    Args:
+        path (str): Filepath to check
     
-    Returns
-    ----------
+    Returns:
         True; if `path` is a valid image filepath
         False; otherwise
+
     """
 
     if not isinstance(path, str):
@@ -324,19 +294,17 @@ def is_image(path):
     return False
 
 
-def is_video(path):
-    """
+def is_video(path) -> bool:
+    r"""
         Checks if a given path is that of a valid image file
             
-    Parameters
-    ----------
-        path : str
-            Filepath to check
+    Args:
+        path (str): Filepath to check
     
-    Returns
-    ----------
+    Returns:
         True; if `path` is a valid image filepath
         False; otherwise
+
     """
     if not isinstance(path, str):
         raise ValueError('path must be a string')
@@ -347,7 +315,7 @@ def is_video(path):
     return False
 
 
-def _is_extension_acceptable(path):
+def _is_extension_acceptable(path) -> bool:
     """
         0 --> Image
         1 --> Video
@@ -375,30 +343,28 @@ def _is_extension_acceptable(path):
         return -1
 
 
-def osname():
+def osname() -> str:
     return os.name
 
 
-def cwd():
-    """
+def cwd() -> str:
+    r"""
         Returns the filepath to the current working directory
     """
     return os.getcwd()
 
 
-def exists(path):
-    """
+def exists(path) -> bool:
+    r"""
         Checks if a given filepath is valid
             
-    Parameters
-    ----------
-        path : str
-            Filepath to check
+    Args:
+        path (str): Filepath to check
     
-    Returns
-    ----------
+    Returns:
         True; if `path` is a valid filepath
         False; otherwise
+
     """
 
     if not isinstance(path, str):
@@ -409,40 +375,56 @@ def exists(path):
     return False
 
 
-def isdir(DIR):
+def isfile(path) -> bool:
+    r"""
+        Checks if a given filepath is a valid path
+            
+    Args:
+        path (str): Filepath to check
+    
+    Returns:
+        True; if `path` is a valid filepath
+        False; otherwise
+
     """
+    return os.path.isfile(path)
+
+
+def isdir(path) -> bool:
+    r"""
         Checks if a given filepath is that of a directory
             
-    Parameters
-    ----------
-        path : str
-            Filepath to check
+    Args:
+        path (str): Filepath to check
     
-    Returns
-    ----------
+    Returns:
         True; if `path` is a valid directory
         False; otherwise
+
     """
-    return os.path.isdir(DIR)
+    return os.path.isdir(path)
 
 
-def mkdir(path):
-    """
+def mkdir(path) -> None:
+    r"""
         Creates a directory at `path`
+
     """
     os.mkdir(path)
 
 
-def abspath(file_name):
-    """
+def abspath(file_name) -> str:
+    r"""
         Returns the absolute path of `file_name`
+
     """
     return os.path.abspath(file_name)
 
 
-def chdir(path):
-    """
+def chdir(path) -> None:
+    r"""
         Checks into directory `path`
+
     """
     if not isinstance(path, str):
         raise ValueError('Specify a valid path')
@@ -450,27 +432,25 @@ def chdir(path):
     os.chdir(path)
 
 
-def get_size(file, disp_format='bytes'):
-    """
-        Returns the size of `file` in bytes/kb/mb/gb/tb
+def get_size(file, disp_format='bytes') -> float:
+    r"""
+        Returns: the size of `file` in bytes/kb/mb/gb/tb
             
-    Parameters
-    ----------
-        file : str
-            Filepath to check
-        disp_format : str
-            Size format (bytes/kb/mb/gb/tb)
+    Args:
+        file (str): Filepath to check
+        disp_format (str): Size format (bytes/kb/mb/gb/tb)
     
-    Returns
-    ----------
-        size : str
-            File size in bytes/kb/mb/gb/tb
+    Returns:
+        size (str): File size in bytes/kb/mb/gb/tb
+
     """
 
     if not isinstance(disp_format, str):
         raise ValueError('display format must be a string')
+    
+    disp_format = disp_format.lower()
 
-    if disp_format.lower() not in ['bytes', 'kb', 'mb', 'gb', 'tb']:
+    if disp_format not in ['bytes', 'kb', 'mb', 'gb', 'tb']:
         raise ValueError('display format needs to be either bytes/kb/mb/gb/tb')
 
     size = os.path.getsize(file)
@@ -491,17 +471,19 @@ def get_size(file, disp_format='bytes'):
         return size * 1e-12
 
 
-def minijoin(*paths):
-    """
+def minijoin(*paths) -> str:
+    r"""
         Join multiple filepaths together
+
     """
 
     return os.path.join(*paths)
 
 
-def dirname(file):
-    """
+def dirname(file) -> str:
+    r"""
         Returns the base directory name of `file`
+
     """
 
     return os.path.dirname(file)
\ No newline at end of file
