@@ -3,7 +3,7 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|  \_
+#  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
@@ -12,8 +12,9 @@
 
 import random
 import time
+import numpy as np
 
-from .utilities import saveNumpy, get_classes_from_dir, to_array, npload
+from .core import get_classes_from_dir, to_array
 from .io import imread
 from .preprocessing import MeanProcess
 from ._internal import _check_target_size, _check_mean_sub_values
@@ -106,7 +107,7 @@ def preprocess_from_dir(DIR,
     if destination_filename is not None and exists(destination_filename):
         print('[INFO] Loading from Numpy Files')
         since = time.time()
-        data = npload(destination_filename, allow_pickle=True)
+        data = np.load(destination_filename, allow_pickle=True)
         end = time.time()
         took = end - since
         print('----------------------------------------------')
@@ -125,11 +126,10 @@ def preprocess_from_dir(DIR,
         since_preprocess = time.time()
 
         if classes is None:
-            classes = get_classes_from_dir(DIR)
+            classes = get_classes_from_dir(DIR)            
             # Removing false folders
             classes = _check_for_false_folders(DIR, classes)
 
-
         if per_class_size is None:
             per_class_size = len(listdir(minijoin(DIR, classes[0]), verbose=0))
 
@@ -188,7 +188,7 @@ def preprocess_from_dir(DIR,
             
             # Saving
             since = time.time()
-            saveNumpy(destination_filename, data)
+            np.save(destination_filename, data)
             end = time.time()
             
             time_elapsed = end-since
@@ -222,7 +222,7 @@ def _check_for_false_folders(base_dir, classes):
         g = []
         for i in classes:
             path = minijoin(base_dir, i)
-            if list_images(path, include_subdirs=False, verbose=0) is not None:
+            if list_images(path, recursive=False, verbose=0) is not None:
                 g.append(i)
     
     return g
