@@ -3,7 +3,7 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|  \_
+#  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
@@ -16,13 +16,10 @@ from .mean_subtraction import compute_mean_from_dir
 from .mean_subtraction import subtract_mean
 from .mean_subtraction import _check_mean_sub_values
 
-from .patch_preprocess import PatchPreprocess
 
 # __all__ globals 
 from .mean_subtraction import __all__ as __all_mean__ 
-from .patch_preprocess import __all__ as __all_patch__ 
 
-__all__ = __all_mean__ + __all_patch__
+__all__ = __all_mean__
 
 del __all_mean__
-del __all_patch__
\ No newline at end of file
