@@ -3,7 +3,7 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|  \_
+#  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
@@ -16,33 +16,38 @@ import cv2 as cv
 
 from .._internal import _check_target_size
 from ..path import list_videos, exists, mkdir
-from ..resize import resize
-from ..globals import FRAME_COUNT, FPS
-from ..io import imsave
+from .constants import FRAME_COUNT, FPS
+from ..io import imsave, resize
 
+__all__ = [
+    'extract_frames'
+]
 
 def extract_frames(input_folder, 
                    output_folder, 
                    target_size=None, 
-                   include_subdirs=False,
+                   recursive=False,
                    label_counter = None, 
                    max_video_count=None, 
                    frames_per_sec=None, 
                    frame_interval=None,
-                   dest_filetype='jpg'):
-    """ Function to extract frames from videos within a directory
-    and save them as separate frames in an output directory.
+                   dest_filetype='jpg') -> int:
+    r"""
+        Extract frames from videos within a directory and save them as separate frames in an output directory.
+
     Args:
-        input_folder: Input video directory.
-        output_folder: Output directory to save the frames.
-        target_size: Destination Image Size (tuple of size 2)
-        label_counter: Starting label counter
-        max_video_count: Number of videos to process.
-        frames_per_sec: Number of frames to process per second. 
-        frame_interval: Interval between the frames to be processed.
-        dest_filetype: Processed image filetype (png, jpg) --> Default: png
+        input_folder (str): Input video directory.
+        output_folder (str): Output directory to save the frames.
+        target_size (tuple): Destination Image Size (tuple of size 2)
+        label_counter (int): Starting label counter (optional)
+        max_video_count (int): Number of videos to process.
+        frames_per_sec (int, float): Number of frames to process per second. 
+        frame_interval (int, float): Interval between the frames to be processed.
+        dest_filetype (str): Processed image filetype (png, jpg). Default: png
+
     Returns:
         label_counter (after processing)
+
     """
 
     dest_filetype.replace('.', '')
@@ -55,7 +60,7 @@ def extract_frames(input_folder,
     if target_size is not None:
         _ = _check_target_size(target_size)
     
-    video_list = list_videos(input_folder, include_subdirs=include_subdirs, use_fullpath=True, verbose=0)
+    video_list = list_videos(input_folder, recursive=recursive, use_fullpath=True, verbose=0)
 
     if len(video_list) == 0:
         raise ValueError(f'No videos found at {input_folder}')
@@ -134,7 +139,7 @@ def extract_frames(input_folder,
     return label_counter
 
 
-def _determine_interval(x):
+def _determine_interval(x) -> int:
     y = '{x:.1f}'
     inde = y.find('.') + 1
     if inde == -1: # if no '.' (if an integer)
@@ -143,8 +148,3 @@ def _determine_interval(x):
         return math.floor(x)
     else:
         return math.ceil(x)
-
-
-__all__ = [
-    'extract_frames'
-]
\ No newline at end of file
