@@ -3,15 +3,15 @@
 # | |        /  \   | |__   | |__) | Caer - Modern Computer Vision
 # | |       / /\ \  |  __|  |  _  /  Languages: Python, C, C++
 # | |___   / ____ \ | |____ | | \ \  http://github.com/jasmcaus/caer
-#  \_____\/_/    \_ \______ |_|  \_
+#  \_____\/_/    \_ \______ |_|  \_\
 
 # Licensed under the MIT License <http://opensource.org/licenses/MIT>
 # SPDX-License-Identifier: MIT
 # Copyright (c) 2020 The Caer Authors <http://github.com/jasmcaus>
 
 
-from .videostream import VideoStream
-
+from .stream import Stream
+from ..path import exists
 
 __all__ = [
     'count_frames',
@@ -20,20 +20,40 @@ __all__ = [
 
 
 def count_frames(video_path=None):
+    r"""
+        Returns the number of frames in a video at ``video_path``.
+
+    Args:
+        video_path (str): Video Filepath
+    
+    Returns:
+        Frame count 
+
+    """
     if video_path is None:
         raise ValueError('Specify a valid video path')
 
-    stream = VideoStream(video_path)
+    stream = Stream(video_path)
     frame_count = stream.count_frames()
     stream.release()
     return frame_count
 
 
 def get_fps(video_path=None):
-    if video_path is None:
+    r"""
+        Returns the FPS in a video at ``video_path``.
+
+    Args:
+        video_path (str): Video Filepath
+    
+    Returns:
+        FPS value. 
+
+    """
+    if video_path is None and not exists(video_path):
         raise ValueError('Specify a valid video path')
 
-    stream = VideoStream(video_path)
+    stream = Stream(video_path)
     fps_count = stream.get_fps()
     stream.release()
     return fps_count
\ No newline at end of file
